from rp.r import *
import rp.prompt_toolkit
def main():
    pterm()
if __name__=='__main__':
    main()